KycConfig class

Constructors

KycConfig({required Color baseColor, required String atlasUrl, KycType type = KycType.bvn, required dynamic onSuccess(dynamic), required String publicKey, required String webVerificationUrl, bool forceWebLaunch = true, required dynamic onErrorMessage(String), String? callbackUrl, required Map<String, dynamic> metaData, String? clientNumber, required dynamic onVerificationFailure(dynamic), String? ref, String? userToken, dynamic onClose(bool, dynamic)?, bool showQrSheet = true, WebviewControls webviewControls = const WebviewControls()})

Properties

atlasUrl → String
Base url for atlas
final
baseColor → Color
The Primary/base color for plugin instance
final
callbackUrl → String?
this field is required by any product doing initiation from central
final
clientNumber ↔ String?
Used to pass in BVN or NIN
getter/setter pair
forceWebLaunch → bool
Force NIN to use webview without attempting native flow
final
hashCode → int
The hash code for this object.
no setterinherited
metaData → Map<String, dynamic>
final
onClose → dynamic Function(bool, dynamic)?
Passed if caller should handle closing plugin
final
onErrorMessage → dynamic Function(String)
Callback to hande to show error messages
final
onSuccess → dynamic Function(dynamic)
Called when verification is successful
final
onVerificationFailure → dynamic Function(dynamic)
Callback from when verification fails
final
publicKey → String
Client public key
final
ref → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showQrSheet → bool
Hide/show the QR sheet that enables the user to scan the verification URL or proceed on device
final
type → KycType
Verification type, only BVN and NIN implemented
final
userToken → String?
final
webVerificationUrl → String
Verification url to launch webview and point verrifcation to web. Only pass in when you want plugin instance to use web sdk
final
webviewControls → WebviewControls
final

Methods

getMetadataAsJson() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setClientNumber(String number) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited