WebviewControls class

Constructors

WebviewControls({void onCopy(String url)?, void onOpenInBrowser(String url)?})
const

Properties

hasCustomControls → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
onCopy → void Function(String url)?
final
onOpenInBrowser → void Function(String url)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited